@ECHO OFF
:*****************Module Header *******************************
:
: Module Name: wlancmd.cmd
:
: Wireless LAN Monitor CMD sample script
:
: Rename this file to xwlan.cmd and palce it into the script
: directory to have it executed on (dis)connect events
:
: See the online help of the Wireless LAN Monitor for further details!
:
: Copyright (c) WLan Project 2004
:
: $Id: xwlancmd.cmd,v 1.1 2004/11/24 21:23:53 cla Exp $
:
: 26-Nov-05  Modified by Chris Clayton to switch between a 'Home' wifi
: (LAN0) profile connection and a wired LAN1 connection using the same
: fixed IP address by turning off and on the radio while the 'Home' profile
: is enabled.  The script also handles changing between the 'Home'
: wifi profile with fixed IP addressing and a 'Travel' public hotspot
: profile using DHCP addressing.  Note:  Connecting from the Public hotspot
: dialog (i.e. no profile) uses the 'Travel' section to remove any LAN1
: TCP/IP settings.  This method of dealing with hotspots has not been tested!
:
: ===========================================================================
:
: This file is part of the WLan Project and is free software.  You can
: redistribute it and/or modify it under the terms of the GNU Library General
: Public License as published by the Free Software Foundation, in version 2
: as it comes in the "COPYING.LIB" file of the WLan Project CVS tree.
: This library is distributed in the hope that it will be useful, but WITHOUT
: ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
: FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
: License for more details.
:
:****************************************************************************

: ------------- save environment and current directory
:
: NOTE:
:  - in opposite to their REXX counterparts, the CMD commands
:    SETLOCAL and ENDLOCAL cannot be nested!
:  - when ENDLOCAL is not executed, CMD.EXE executes it
:    implicitely at the end of a script!
:  - when calling another CMD script from here, this script
:    already will execute an ENDLOCAL (explicitely or inplicitely)

 SETLOCAL

: ------------- echo the event to have it in the logfile

 ECHO EVENT       = %WLAN_EVENT%
 ECHO PROFILENAME = %WLAN_PROFILENAME%
 ECHO SSID        = %WLAN_SSID%

: ------------- check for the access point connected to
: NOTE:
: - if the SSID is not handled by the script, because it does
:   not exist as a batch label, the script aborts with an error message.
:   This is less overhead than checking every single name explicitely here.

: IF .%WLAN_SSID% == . GOTO end
: GOTO %WLAN_SSID%

: ------------- connect and disconncet code for specific access points
: NOTE:
: - the System Service Identifier is case sensitive !!!
: - CMD.EXE distincts batch labes only for the first eight characters,
:   so we have to abbreviate the SSID to the shortest possible name
:   (maximum seven characters), here we use "N_"

:: The SSID test sometimes fails on disconnect.  When the radio is turned off?
:: The SSID is a NULL string.  So substituted the profile name
IF .%WLAN_PROFILENAME% == . GOTO NOPROFILE
GOTO %WLAN_PROFILENAME%

:: Change between wifi and wired LANs when at home
:: This method works well when the radio is turned off & on
::   but leaves something to be desired when changing between profiles
:Home
 GOTO H_%WLAN_EVENT%

:: Make sure wired LAN1 is removed, then setup wifi LAN0 using fixed IP
:: Included a statement to make sure PEER is stopped. This can be time
::   consuming, but may avoid problems if I forget to do it manually
:: To avoid a duplicate address popup, I disabled TCP/IP setup in the 'Home'
::   profile and do the configuration here
:: In case we are changing from a DHCP configuration, I also make sure that
::   name resolution is correct.
:H_CONNECT
 net stop req /y
 ifconfig lan1 down
 ifconfig lan1 delete
 route -fh
 arp -f
 ifconfig lan0 192.168.2.56 netmask 255.255.255.0 metric 0 mtu 1500
 route add default 192.168.2.50 -hopcount 2
 copy d:\mptn\etc\resolv.aps d:\mptn\etc\resolv2
 ECHO Changed to home wifi
 GOTO end

::  Setup wired LAN1 to use the same fixed IP address
:H_DISCONNECT
 net stop req /y
 ifconfig lan0 down
 ifconfig lan0 delete
 route -fh
 arp -f
 ifconfig lan1 192.168.2.56 netmask 255.255.255.0 metric 0 mtu 1500
 route add default 192.168.2.50 -hopcount 2
 ECHO Changed to home wired
 GOTO end

:: Attach to a public hotspot and use DHCP to configure wifi
:NOPROFILE
:Travel
 GOTO T_%WLAN_EVENT%

:: The undesirable part of this method is that the LAN1 configuration
::   setup when the 'Home' profile disconnected needs to be removed.
:: The DHCP config is setup using the 'Travel' profile
:T_CONNECT
 net stop req /y
 ifconfig lan1 down
 ifconfig lan1 delete
 ECHO Changed to travel wifi
 GOTO end

:T_DISCONNECT
 ECHO Disconnected from travel hotspot
 GOTO end

:end

: ------------- reset environment and current directory
 ENDLOCAL

